@@ -11,6 +11,10 @@
 #'   the working directory (\code{getwd()}). Default for \code{load_models} is
 #'   to open a dialog box from which a file can be selected, in which case a
 #'   message will issued with code to load the same file without interactivity.
+#' @param sanitize_phi Logical. If TRUE (default) training data is removed from
+#'   the model object before being saved. Removing training data is important
+#'   when sharing models that were trained with data that contain PHI. If
+#'   removed, \code{\link{explore}} will not have data to process.
 #' @return \code{load_models} returns the model_list which can be assigned to
 #'   any variable name
 #'
@@ -24,10 +28,16 @@
 #' m2 <- load_models("diabetes_models.RDS")
 #' all.equal(m, m2)
 #' }
-save_models <- function(x, filename = "models.RDS") {
+save_models <- function(x, filename = "models.RDS", sanitize_phi = TRUE) {
+  if (sanitize_phi) {
+    attr(x, "recipe")$template <- NULL
+    attr(x, "recipe")$orig_data <- NULL
+  } else {
+    message("The model object being saved contains training data, minus ",
+            "ignored ID columns.\nIf there was PHI in training data, normal ",
+            "PHI protocols apply to the RDS file.")
+  }
   saveRDS(x, filename)
-  message("The model object being saved contains training data, minus ignored ID columns.\n",
-          "If there was PHI in training data, normal PHI protocols apply to the RDS file.")
   return(invisible(NULL))
 }
 
@@ -36,11 +46,14 @@ save_models <- function(x, filename = "models.RDS") {
 load_models <- function(filename) {
   if (missing(filename)) {
     filename <- file.choose()
-    mes <- paste0("Loading models. You could automate this with `load_models(",
-                  filename, ")`")
+    mes <- paste0('Loading models. You could automate this with `load_models("',
+                  filename, '")`')
     message(mes)
   }
   x <- readRDS(filename)
   attr(x, "loaded_from_rds") <- filename
+  if (!is.null(attr(x, "recipe")$template) | !is.null(attr(x, "recipe")$orig_data))
+    message("*** If there was PHI in training data, normal PHI protocols apply",
+            " to this model object. ***")
   return(x)
 }
